Scans continuous data for artifacts using amplitude or gradient criteria.
Usage
detectArtifacts(
x,
method = c("amplitude", "gradient", "joint"),
threshold = NULL,
window_sec = 1
)Scans continuous data for artifacts using amplitude or gradient criteria.
detectArtifacts(
x,
method = c("amplitude", "gradient", "joint"),
threshold = NULL,
window_sec = 1
)