Replaces bad channels with interpolated values from neighboring channels.
Usage
interpolateBadChannels(
x,
bad_channels,
method = c("average", "spline"),
output_assay = "interpolated"
)Replaces bad channels with interpolated values from neighboring channels.
interpolateBadChannels(
x,
bad_channels,
method = c("average", "spline"),
output_assay = "interpolated"
)