Skip to contents

Per-section analogue of lfilterInit for second-order-sections form; equivalent to scipy.signal.sosfilt_zi. Each section's steady state is scaled by the DC gain of all preceding sections so that the whole cascade starts in steady state when the returned matrix (scaled by the first sample) is handed to sosfilt.

Usage

sosfiltInit(sos)

Arguments

sos

SOS matrix (n_sections x 6).

Value

A numeric matrix (n_sections x 2) of per-section initial states (unscaled).

See also

Examples

sos <- sosDesign(high = 40, type = "low", sr = 250)
zi <- sosfiltInit(sos)